package com.huigou.topsun.ep.epApplication;

import com.huigou.topsun.ep.epApplication.EpVo.EpProductInfoVo;

import java.util.List;
import java.util.Map;

/**
 * @Auther: xin.lu
 * @Date: 2024/06/22/15:23
 * @Description:
 */
public interface EpApplication {
    List<Map<String, String>> queryEpBrand(String brandName);

    List<Map<String, String>> queryEpPd(String brandCode);

    List<Map<String, String>> queryProductAndBom(String itemCode);

    /**
     *
     * @param matnr2 产品编码
     * @return
     */
    EpProductInfoVo queryEpProductInfo(String matnr2);

    /**
     * 根据产品编码查询工序
     * @param itemCode
     * @return
     */
    List<Map<String, String>> queryEpProductProcess(String itemCode);

    /**
     * 根据产品编码查询品牌
     * @param itemCode
     * @return
     */
    List<Map<String, String>> queryEpBrandByItemCode(String itemCode);

    /**
     * 查询ep打样产品信息
     */
    List<Map<String,String>> queryEpProofingProduct();

    /**
     * 根据打样单号查询打样产品信息
     * @param proofingNo
     * @return
     */
    List<Map<String,String>> queryEpProductProcessByProofingNo(String proofingNo);
}
